@@ -14,7 +14,7 @@ def create_settings(spider_path, user_redis=False, *args, **kwargs):
     settings.JS_PATH = str(get_run_py_dir() / "js_path") # can be a custom path string, or True to use the default: get_run_py_dir() / "js_path"
 
     if user_redis:
-        settings.SCHEDULER = "scrapy_cffi.scheduler.RedisScheduler" # 启动 redis 调度器需要配置 redis 信息
+        settings.SCHEDULER = "scrapy_cffi.scheduler.RedisScheduler" # Starting the Redis scheduler requires configuring Redis information
         settings.REDIS_INFO.REDIS_URL = "redis://127.0.0.1:6379"
     
     # settings.LOG_INFO.LOG_ENABLED = False
